A dataset containing daily temperature, log precipitation and wind speed of 73 spanish weather stations in Spain between 1980 - 2009.
spanish_weatherA list containing :
$station_info:A dataframe containing geographic information from the 73 weather stations with the following variables:
ind:id of weather station
name:name of weather station
province:province of weather station
altitude:altitude in meters of the station
year.ini:start year
year.end:end year
longitude:longitude of the coordinates of the weather station (in decimal degrees)
longitude:latitude of the coordinates of the weather station (in decimal degrees)
$temperature:A matrix of size 73 (stations) by 365 (days) containing average daily temperature for the period 1980-2009 (in degrees Celsius, marked with UTF-8 string). Leap years temperatures for February 28 and 29 were averaged.
$wind_speed:A matrix of size 73 (stations) by 365 (days) containing average daily wind speed for the period 1980-2009 (in m/s).
$logprec:A matrix of size 73 (stations) by 365 (days) containing average daily log precipitation
for the period 1980-2009 (in log mm). Negligible precipitation (less than 1 tenth of mm)
is replaced by 0.05 and no precipitation (0.0 mm) is replaced by 0.01 after which
the logarithm was applied.
This is a stripped down version of the popular aemet spanish weather data available in
the fda.usc tools:::Rd_expr_doi("10.18637/jss.v051.i04") package.
See the documentation of fda.usc for more details about data.
data(spanish_weather)
names(spanish_weather)
names(spanish_weather$station_info)
Run the code above in your browser using DataLab